==> open-cluster-management-cluster-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.model.Condition;
import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PlacementStatusFluentImpl<A extends PlacementStatusFluent<A>> extends BaseFluent<A> implements PlacementStatusFluent<A>{
  public PlacementStatusFluentImpl() {
  }
  public PlacementStatusFluentImpl(PlacementStatus instance) {
    this.withConditions(instance.getConditions()); 
    this.withNumberOfSelectedClusters(instance.getNumberOfSelectedClusters()); 
  }
  private List<Condition> conditions = new ArrayList<Condition>();
  private Integer numberOfSelectedClusters;
  public A addToConditions(Integer index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    this.conditions.add(index, item);
    return (A)this;
  }
  public A setToConditions(Integer index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    this.conditions.set(index, item); return (A)this;
  }
  public A addToConditions(io.fabric8.kubernetes.api.model.Condition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    for (Condition item : items) {this.conditions.add(item);} return (A)this;
  }
  public A addAllToConditions(Collection<Condition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    for (Condition item : items) {this.conditions.add(item);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.kubernetes.api.model.Condition... items) {
    for (Condition item : items) {if (this.conditions!= null){ this.conditions.remove(item);}} return (A)this;
  }
  public A removeAllFromConditions(Collection<Condition> items) {
    for (Condition item : items) {if (this.conditions!= null){ this.conditions.remove(item);}} return (A)this;
  }
  public List<Condition> getConditions() {
    return this.conditions;
  }
  public Condition getCondition(Integer index) {
    return this.conditions.get(index);
  }
  public Condition getFirstCondition() {
    return this.conditions.get(0);
  }
  public Condition getLastCondition() {
    return this.conditions.get(conditions.size() - 1);
  }
  public Condition getMatchingCondition(Predicate<Condition> predicate) {
    for (Condition item: conditions) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingCondition(Predicate<Condition> predicate) {
    for (Condition item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(List<Condition> conditions) {
    if (conditions != null) {this.conditions = new ArrayList(); for (Condition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.kubernetes.api.model.Condition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (Condition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public Integer getNumberOfSelectedClusters() {
    return this.numberOfSelectedClusters;
  }
  public A withNumberOfSelectedClusters(Integer numberOfSelectedClusters) {
    this.numberOfSelectedClusters=numberOfSelectedClusters; return (A) this;
  }
  public Boolean hasNumberOfSelectedClusters() {
    return this.numberOfSelectedClusters != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PlacementStatusFluentImpl that = (PlacementStatusFluentImpl) o;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    if (numberOfSelectedClusters != null ? !numberOfSelectedClusters.equals(that.numberOfSelectedClusters) :that.numberOfSelectedClusters != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  numberOfSelectedClusters,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (numberOfSelectedClusters != null) { sb.append("numberOfSelectedClusters:"); sb.append(numberOfSelectedClusters); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.model.Condition;
import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PlacementStatusFluentImpl<A extends PlacementStatusFluent<A>> extends BaseFluent<A> implements PlacementStatusFluent<A>{
  public PlacementStatusFluentImpl() {
  }
  public PlacementStatusFluentImpl(PlacementStatus instance) {
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withNumberOfSelectedClusters(instance.getNumberOfSelectedClusters());
    }
  }
  private List<Condition> conditions = new ArrayList<Condition>();
  private Integer numberOfSelectedClusters;
  public A addToConditions(int index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    this.conditions.add(index, item);
    return (A)this;
  }
  public A setToConditions(int index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    this.conditions.set(index, item); return (A)this;
  }
  public A addToConditions(io.fabric8.kubernetes.api.model.Condition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    for (Condition item : items) {this.conditions.add(item);} return (A)this;
  }
  public A addAllToConditions(Collection<Condition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    for (Condition item : items) {this.conditions.add(item);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.kubernetes.api.model.Condition... items) {
    for (Condition item : items) {if (this.conditions!= null){ this.conditions.remove(item);}} return (A)this;
  }
  public A removeAllFromConditions(Collection<Condition> items) {
    for (Condition item : items) {if (this.conditions!= null){ this.conditions.remove(item);}} return (A)this;
  }
  public List<Condition> getConditions() {
    return this.conditions;
  }
  public Condition getCondition(int index) {
    return this.conditions.get(index);
  }
  public Condition getFirstCondition() {
    return this.conditions.get(0);
  }
  public Condition getLastCondition() {
    return this.conditions.get(conditions.size() - 1);
  }
  public Condition getMatchingCondition(Predicate<Condition> predicate) {
    for (Condition item: conditions) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingCondition(Predicate<Condition> predicate) {
    for (Condition item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(List<Condition> conditions) {
    if (conditions != null) {this.conditions = new ArrayList(); for (Condition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.kubernetes.api.model.Condition... conditions) {
    if (this.conditions != null) {this.conditions.clear(); _visitables.remove("conditions"); }
    if (conditions != null) {for (Condition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public Integer getNumberOfSelectedClusters() {
    return this.numberOfSelectedClusters;
  }
  public A withNumberOfSelectedClusters(Integer numberOfSelectedClusters) {
    this.numberOfSelectedClusters=numberOfSelectedClusters; return (A) this;
  }
  public Boolean hasNumberOfSelectedClusters() {
    return this.numberOfSelectedClusters != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementStatusFluentImpl that = (PlacementStatusFluentImpl) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;

    if (!java.util.Objects.equals(numberOfSelectedClusters, that.numberOfSelectedClusters)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  numberOfSelectedClusters,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (numberOfSelectedClusters != null) { sb.append("numberOfSelectedClusters:"); sb.append(numberOfSelectedClusters); }
    sb.append("}");
    return sb.toString();
  }
  
}
